@@ -1,7 +1,7 @@
 /* sercomm.c
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -56,14 +56,22 @@ brl_ser_open_port (gint port)
 
     switch (port)
     {
-	case 1:
+	case 0:
 	    pname = TTYNAME0; 	
 	break;
     
-	case 2:
+	case 1:
 	    pname = TTYNAME1;
 	break;
 	
+	case 2:
+	    pname = TTYNAME2; 	
+	break;
+    
+	case 3:
+	    pname = TTYNAME3;
+	break;
+
 	default:
 	    fprintf (stderr, "\nbrl_open_port: Invalid serial port number %d", port);
 	    return 0;
@@ -134,6 +142,42 @@ handy_set_comm_param()
     return 1;
 }
 
+/*for Eco devices */
+gint 
+eco_set_comm_param()
+{
+    struct termios options;
+
+    /* get the current options from the port */
+    tcgetattr (fd_serial, &options);
+
+    /* set control flags */
+    options.c_cflag = CS8|CLOCAL|CREAD;
+    options.c_cflag &= ~CRTSCTS;  /* disable hardware flow control */
+
+    /* set input flags */
+    options.c_iflag &= ~(IXON|IXOFF|IXANY);  /* disable software flow control */
+    options.c_iflag = IGNPAR;
+
+    /* set output and local flags to zero */
+    options.c_oflag = 0;
+    options.c_lflag = 0;
+
+    /* set number of min chars to sigio */
+    options.c_cc[VMIN] = 9;
+    options.c_cc[VTIME] = 0;
+
+    /* set the port speed */
+    cfsetispeed(&options,B19200);
+    cfsetospeed(&options,B19200);
+
+    /* set the options for the port */
+    tcsetattr (fd_serial, TCSANOW, &options);
+
+    return 1;
+}
+
+
 gint 
 brl_ser_set_comm_param (glong  baud_rate, 
 			gchar  parity, 
@@ -370,7 +414,7 @@ void
 static gboolean 
 brl_ser_glib_cb (GIOChannel   *source, 
 		 GIOCondition condition, 
-		 gpointer     data)
+		 gpointer     unused)
 {			
     gint n, i;
     guchar data[256];
