@@ -1,8 +1,8 @@
 /* ttybrl.c
  *
- * Copyright 2003, Mario Lang
- * Copyright 2003, BAUM Retec A.G.
- * Copyright 2003, Sun Microsystems Inc. 
+ * Copyright 2003 - 2005 Mario Lang
+ * Copyright 2003 - 2005 BAUM Retec A.G.
+ * Copyright 2003 - 2005 Sun Microsystems Inc. 
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -32,11 +32,17 @@
 #include <string.h>
 
 #include <glib.h>
+#include <gdk/gdkwindow.h>
+#include <gdk/gdkproperty.h>
+#include <gdk/gdkx.h>
 
 #include <brltty/brldefs.h>
 #include <brltty/api.h>
 
+#include <X11/Xatom.h>
+
 #include "braille.h"
+#include "srintl.h"
 
 typedef struct
 {
@@ -104,7 +110,10 @@ brltty_brl_send_dots (guchar 	*dots,
     if (brlapi_write(&ws) == 0) 
 	return 1;
     else 
+    {
+        brlapi_perror("brlapi_write");
 	return 0;
+    }
 }
 
 void
@@ -181,6 +190,7 @@ brltty_brl_glib_cb (GIOChannel   *source,
 			client_callback (bec, &bed);
 		    break;
 		    default:
+			//to be translated
 			fprintf(stderr,"BRLTTY command code not bound to Gnopernicus key code: 0X%04X\n", keypress);
 		    break;
     		}
@@ -194,7 +204,10 @@ brltty_brl_glib_cb (GIOChannel   *source,
 static void
 ignore_block (gint block)
 {
-    brlapi_ignoreKeyRange(block, block|BRL_MSK_ARG);
+    if (brlapi_ignoreKeyRange(block, block|BRL_MSK_ARG) == -1) {
+	brlapi_perror("brlapi_ignoreKeyRange");
+	fprintf(stderr,"(block 0x%x)", block);
+    }
 }
 
 static void
@@ -231,20 +244,31 @@ brltty_brl_open_device (gchar* 			device_name,
 			BRLDevice 		*device)
 {
     gint fd;
+    brlapi_settings_t settings;
+    GdkWindow *root;
+    GdkAtom VTAtom, type;
+    guint VT = 0;
+    gint format, length;
+    unsigned char *buf;
 
-    if ((fd = brlapi_initializeConnection (NULL, NULL)) < 0) 
+
+    if ((fd = brlapi_initializeConnection (NULL, &settings)) < 0) 
     {
-	brlapi_perror("Error opening brlapi connection");
+	brlapi_perror("Error opening brlapi connection"); //to be translated
+	fprintf(stderr,"Please check that\n\
+ - %s exists and contains some data\n\
+ - you have read permission on %s\n\
+ - BRLTTY is running\n", settings.authKey, settings.authKey); //to be translated
 	return 0;
     }
 
     if (brlapi_getDisplaySize (&dd.x, &dd.y) != 0) 
     {
-	brlapi_perror("Unable to get display size");
+	brlapi_perror("Unable to get display size"); //to be translated
 	return 0;
     }
 
-    fprintf(stderr, "BrlAPI detected a %dx%d display\n", dd.x, dd.y);
+    fprintf(stderr, "BrlAPI detected a %dx%d display\n", dd.x, dd.y); //to be translated
 
     device->cell_count = dd.x * dd.y;
     device->display_count = 1; /* No status cells implemented yet */
@@ -263,13 +287,70 @@ brltty_brl_open_device (gchar* 			device_name,
 
     client_callback = device_callback;
 
-    /* TODO: Write a function which reliably determines the TTY
-     where the X server is running.  
-     Currently if the tty is set to 0 the function brlapi_getTty will look at the CONTROLVT environment
-     variable
+    /* Determine the TTY where the X server is running.  
+
+     This only works with XFree86 starting from 4.3.99.903 and X.Org
+     starting from 6.8.0
+
+     If you have an older version, the tty will be kept to 0 so that the
+     brlapi_getTty() function will look at the CONTROLVT environment variable.
+     So people having old versions should have something like this in their
+     .xsession, before launching gnopernicus:
+
      CONTROLVT="$(grep "using VT number" "/var/log/XFree86.$(echo "$DISPLAY" | sed -e "s/^.*::*\([0-9]*\).*$/\1/").log" | sed -e "s/^.*using VT number \([0-9]*\).*$/\1/")"
+
+     for XFree86
+
+     CONTROLVT="$(grep "using VT number" "/var/log/Xorg.$(echo "$DISPLAY" | sed -e "s/^.*::*\([0-9]*\).*$/\1/").log" | sed -e "s/^.*using VT number \([0-9]*\).*$/\1/")"
+
+     for X.Org
+
     */
-    brlapi_getTty (0, BRLCOMMANDS);
+
+    root = gdk_get_default_root_window();
+    if (!root)
+	goto gettty;
+
+    VTAtom = gdk_atom_intern("XFree86_VT", TRUE);
+    if (VTAtom == None)
+	goto gettty;
+
+    if (!(gdk_property_get(root, VTAtom, AnyPropertyType, 0, 1, FALSE,
+	    &type, &format, &length, &buf)))
+    {
+	fprintf(stderr, "no XFree86_VT property\n"); //to be translated
+	goto gettty;
+    }
+
+    if (length<1)
+    {
+	fprintf(stderr, "no item in XFree86_VT property\n"); //to be translated
+    	goto gettty;
+    }
+
+    switch ((guint)type)
+    {
+	case XA_CARDINAL:
+	case XA_INTEGER:
+	case XA_WINDOW:
+	    switch (format)
+	    {
+		case 8:  VT = (*(guint8  *)buf); break;
+		case 16: VT = (*(guint16 *)buf); break;
+		case 32: VT = (*(guint32 *)buf); break;
+		default: fprintf(stderr, "Bad format for VT number\n"); break; //to be translated
+	    }
+	    break;
+	default:
+	    fprintf(stderr, "Bad type for VT number\n"); //to be translated
+    }
+
+gettty:
+    if (brlapi_getTty (VT, BRLCOMMANDS) == -1)
+    {
+	brlapi_perror("Unable to get Tty"); //to be translated
+	return 0;
+    }
 
     ignore_input(BRL_BLK_PASSCHAR);
     ignore_input(BRL_BLK_PASSDOTS);
