@@ -1,7 +1,7 @@
 /* brlconf.c
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -47,7 +47,7 @@ extern GConfClient *gnopernicus_client;
  * Braille config setting
  *
 **/
-Braille 	*braille_setting;
+extern Braille 	*braille_setting;
 gint     br_notify_id;
 GList 	*brldev_id_list = NULL;
 GList	*brldev_description_list = NULL;	
