@@ -109,7 +109,8 @@ GtkWidget		*w_braille_device;
 static GtkWidget 	*cb_braille_device;
 static GtkWidget 	*cb_port;
 static GtkWidget	*lb_port;
-
+static GtkWidget	*ck_man_port;
+static GtkWidget 	*et_man_port;
 /**
  * Translation Table widgets 					
 **/
@@ -405,6 +406,15 @@ brlui_delete_emit_response_cancel (GtkDialog *dialog,
     return TRUE; /* Do not destroy */
 }
 
+static void
+brlui_braille_device_ck_man_port_toggled (GtkToggleButton *button, 
+					  gpointer user_data)
+{
+    gboolean state = gtk_toggle_button_get_active (button);
+    
+    gtk_widget_set_sensitive (et_man_port, state);
+    /* will be kept in gconf also & stuff */
+}
 
 void 
 brlui_set_handlers_braille_device (GladeXML *xml,
@@ -414,6 +424,8 @@ brlui_set_handlers_braille_device (GladeXML *xml,
     cb_braille_device = glade_xml_get_widget (xml, "cb_braille_device");
     cb_port 	      = glade_xml_get_widget (xml, "cb_port");
     lb_port 	      = glade_xml_get_widget (xml, "lb_port");
+    ck_man_port	      = glade_xml_get_widget (xml, "ck_man_port");
+    et_man_port	      = glade_xml_get_widget (xml, "et_man_port");
 
     g_signal_connect (w_braille_device, "response",
 		      G_CALLBACK (brlui_settings_response_braille_device), 
@@ -423,6 +435,9 @@ brlui_set_handlers_braille_device (GladeXML *xml,
 
     glade_xml_signal_connect (xml,"on_combo-entry1_changed",		
 			    GTK_SIGNAL_FUNC (brlui_braille_device_combo_changed));
+			    
+    glade_xml_signal_connect (xml,"on_ck_man_port_toggled",		
+			    GTK_SIGNAL_FUNC (brlui_braille_device_ck_man_port_toggled));
 
     gtk_entry_set_editable (GTK_ENTRY (GTK_COMBO (cb_braille_device)->entry), FALSE);
 }
