@@ -1,7 +1,7 @@
 /* magconf.h
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -67,8 +67,8 @@ typedef struct
 	gboolean	invert;
 	gboolean	panning;
 	
-	gint		zoomfactorx;
-	gint		zoomfactory;
+	gdouble		zoomfactorx;
+	gdouble		zoomfactory;
 	gboolean 	zoomfactor_lock;
 	
 	gchar		*smoothing;
