@@ -679,9 +679,11 @@ src_process_config_changed_for_braille (SRConfigStructure *config)
     sru_assert (config->key);
     if (strcmp (config->key, BRAILLE_DEVICE) == 0)
     {
+	gboolean rv;
+
 	sru_assert (config->newvalue && config->type == CFGT_STRING);
 	
-	gboolean rv = src_braille_set_device ((gchar*)config->newvalue);   
+	rv = src_braille_set_device ((gchar*)config->newvalue);   
 	if (!rv)
 	{
 	    sru_message ("SR: process config changed for braille: brl_device did not change!!!");
@@ -713,9 +715,11 @@ src_process_config_changed_for_braille (SRConfigStructure *config)
     }
     else if (strcmp (config->key, BRAILLE_TRANSLATION) == 0)
     {
+	gboolean rv;
+
     	sru_assert (config->type == CFGT_STRING && config->newvalue);
 	
-	gboolean rv = src_braille_set_translation_table ((gchar*)config->newvalue);
+	rv = src_braille_set_translation_table ((gchar*)config->newvalue);
 	
 	if (!rv)
 	{
