@@ -1,7 +1,7 @@
  /* srspc.c
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -1749,11 +1749,11 @@ src_speech_translate_symbol (gint index)
 	    src_speech_dictionary[index].character == '!' ||
 	    src_speech_dictionary[index].character == '?')
 	{
-	    rv = g_strconcat ("  ", src_speech_dictionary[index].singular, " ", NULL);
+	    rv = g_strconcat ("  ", _(src_speech_dictionary[index].singular), " ", NULL);
 	    rv[0] = src_speech_dictionary[index].character;
 	}
 	else
-	    rv = g_strconcat (" ", src_speech_dictionary[index].singular, " ", NULL);
+	    rv = g_strconcat (" ", _(src_speech_dictionary[index].singular), " ", NULL);
     }
     else
     {
@@ -1788,8 +1788,8 @@ src_speech_count_symbol (gchar *start,
 	rv = g_strndup (start, 1);
     else
 	rv = g_strconcat (count, " ",
-	    cnt == 1 ? src_speech_dictionary[index].singular : 
-					src_speech_dictionary[index].plural,
+	    cnt == 1 ? _(src_speech_dictionary[index].singular) : 
+					_(src_speech_dictionary[index].plural),
 	    " ", NULL);
     *new_pos = crt;
     return rv;
@@ -1826,7 +1826,7 @@ src_speech_process_string (const gchar   *text,
     {
         gint index = src_speech_get_index_for_symbol (crt[0]);
 	if (index != -1)
-	    return g_strdup (src_speech_dictionary[index].singular);
+	    return g_strdup (_(src_speech_dictionary[index].singular));
 	else
 	    return g_strdup ((gchar*)text);
     }
